@@ -25,7 +25,9 @@ __all__ = (
     "OperatorTypeType",
     "QueryObjectsPaginatorName",
     "TaskStatusType",
+    "DataPipelineServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -35,6 +37,7 @@ ListPipelinesPaginatorName = Literal["list_pipelines"]
 OperatorTypeType = Literal["BETWEEN", "EQ", "GE", "LE", "REF_EQ"]
 QueryObjectsPaginatorName = Literal["query_objects"]
 TaskStatusType = Literal["FAILED", "FALSE", "FINISHED"]
+DataPipelineServiceName = Literal["datapipeline"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -66,6 +69,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -188,6 +192,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -336,4 +341,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["describe_objects", "list_pipelines", "query_objects"]
