@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import OperatorTypeType, TaskStatusType
 
 if sys.version_info >= (3, 9):
@@ -74,27 +76,14 @@ __all__ = (
     "ValidationWarningTypeDef",
 )
 
-_RequiredActivatePipelineInputRequestTypeDef = TypedDict(
-    "_RequiredActivatePipelineInputRequestTypeDef",
+ActivatePipelineInputRequestTypeDef = TypedDict(
+    "ActivatePipelineInputRequestTypeDef",
     {
         "pipelineId": str,
+        "parameterValues": NotRequired[Sequence["ParameterValueTypeDef"]],
+        "startTimestamp": NotRequired[Union[datetime, str]],
     },
 )
-_OptionalActivatePipelineInputRequestTypeDef = TypedDict(
-    "_OptionalActivatePipelineInputRequestTypeDef",
-    {
-        "parameterValues": Sequence["ParameterValueTypeDef"],
-        "startTimestamp": Union[datetime, str],
-    },
-    total=False,
-)
-
-
-class ActivatePipelineInputRequestTypeDef(
-    _RequiredActivatePipelineInputRequestTypeDef, _OptionalActivatePipelineInputRequestTypeDef
-):
-    pass
-
 
 AddTagsInputRequestTypeDef = TypedDict(
     "AddTagsInputRequestTypeDef",
@@ -104,28 +93,15 @@ AddTagsInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredCreatePipelineInputRequestTypeDef = TypedDict(
-    "_RequiredCreatePipelineInputRequestTypeDef",
+CreatePipelineInputRequestTypeDef = TypedDict(
+    "CreatePipelineInputRequestTypeDef",
     {
         "name": str,
         "uniqueId": str,
+        "description": NotRequired[str],
+        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreatePipelineInputRequestTypeDef = TypedDict(
-    "_OptionalCreatePipelineInputRequestTypeDef",
-    {
-        "description": str,
-        "tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreatePipelineInputRequestTypeDef(
-    _RequiredCreatePipelineInputRequestTypeDef, _OptionalCreatePipelineInputRequestTypeDef
-):
-    pass
-
 
 CreatePipelineOutputTypeDef = TypedDict(
     "CreatePipelineOutputTypeDef",
@@ -135,26 +111,13 @@ CreatePipelineOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredDeactivatePipelineInputRequestTypeDef = TypedDict(
-    "_RequiredDeactivatePipelineInputRequestTypeDef",
+DeactivatePipelineInputRequestTypeDef = TypedDict(
+    "DeactivatePipelineInputRequestTypeDef",
     {
         "pipelineId": str,
+        "cancelActive": NotRequired[bool],
     },
 )
-_OptionalDeactivatePipelineInputRequestTypeDef = TypedDict(
-    "_OptionalDeactivatePipelineInputRequestTypeDef",
-    {
-        "cancelActive": bool,
-    },
-    total=False,
-)
-
-
-class DeactivatePipelineInputRequestTypeDef(
-    _RequiredDeactivatePipelineInputRequestTypeDef, _OptionalDeactivatePipelineInputRequestTypeDef
-):
-    pass
-
 
 DeletePipelineInputRequestTypeDef = TypedDict(
     "DeletePipelineInputRequestTypeDef",
@@ -163,28 +126,15 @@ DeletePipelineInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDescribeObjectsInputRequestTypeDef = TypedDict(
-    "_RequiredDescribeObjectsInputRequestTypeDef",
+DescribeObjectsInputRequestTypeDef = TypedDict(
+    "DescribeObjectsInputRequestTypeDef",
     {
         "pipelineId": str,
         "objectIds": Sequence[str],
+        "evaluateExpressions": NotRequired[bool],
+        "marker": NotRequired[str],
     },
 )
-_OptionalDescribeObjectsInputRequestTypeDef = TypedDict(
-    "_OptionalDescribeObjectsInputRequestTypeDef",
-    {
-        "evaluateExpressions": bool,
-        "marker": str,
-    },
-    total=False,
-)
-
-
-class DescribeObjectsInputRequestTypeDef(
-    _RequiredDescribeObjectsInputRequestTypeDef, _OptionalDescribeObjectsInputRequestTypeDef
-):
-    pass
-
 
 DescribeObjectsOutputTypeDef = TypedDict(
     "DescribeObjectsOutputTypeDef",
@@ -228,47 +178,22 @@ EvaluateExpressionOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredFieldTypeDef = TypedDict(
-    "_RequiredFieldTypeDef",
+FieldTypeDef = TypedDict(
+    "FieldTypeDef",
     {
         "key": str,
+        "stringValue": NotRequired[str],
+        "refValue": NotRequired[str],
     },
 )
-_OptionalFieldTypeDef = TypedDict(
-    "_OptionalFieldTypeDef",
-    {
-        "stringValue": str,
-        "refValue": str,
-    },
-    total=False,
-)
 
-
-class FieldTypeDef(_RequiredFieldTypeDef, _OptionalFieldTypeDef):
-    pass
-
-
-_RequiredGetPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_RequiredGetPipelineDefinitionInputRequestTypeDef",
+GetPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "GetPipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
+        "version": NotRequired[str],
     },
 )
-_OptionalGetPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_OptionalGetPipelineDefinitionInputRequestTypeDef",
-    {
-        "version": str,
-    },
-    total=False,
-)
-
-
-class GetPipelineDefinitionInputRequestTypeDef(
-    _RequiredGetPipelineDefinitionInputRequestTypeDef,
-    _OptionalGetPipelineDefinitionInputRequestTypeDef,
-):
-    pass
-
 
 GetPipelineDefinitionOutputTypeDef = TypedDict(
     "GetPipelineDefinitionOutputTypeDef",
@@ -283,18 +208,16 @@ GetPipelineDefinitionOutputTypeDef = TypedDict(
 InstanceIdentityTypeDef = TypedDict(
     "InstanceIdentityTypeDef",
     {
-        "document": str,
-        "signature": str,
+        "document": NotRequired[str],
+        "signature": NotRequired[str],
     },
-    total=False,
 )
 
 ListPipelinesInputRequestTypeDef = TypedDict(
     "ListPipelinesInputRequestTypeDef",
     {
-        "marker": str,
+        "marker": NotRequired[str],
     },
-    total=False,
 )
 
 ListPipelinesOutputTypeDef = TypedDict(
@@ -310,20 +233,18 @@ ListPipelinesOutputTypeDef = TypedDict(
 OperatorTypeDef = TypedDict(
     "OperatorTypeDef",
     {
-        "type": OperatorTypeType,
-        "values": Sequence[str],
+        "type": NotRequired[OperatorTypeType],
+        "values": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 ParameterAttributeTypeDef = TypedDict(
@@ -350,37 +271,23 @@ ParameterValueTypeDef = TypedDict(
     },
 )
 
-_RequiredPipelineDescriptionTypeDef = TypedDict(
-    "_RequiredPipelineDescriptionTypeDef",
+PipelineDescriptionTypeDef = TypedDict(
+    "PipelineDescriptionTypeDef",
     {
         "pipelineId": str,
         "name": str,
         "fields": List["FieldTypeDef"],
+        "description": NotRequired[str],
+        "tags": NotRequired[List["TagTypeDef"]],
     },
 )
-_OptionalPipelineDescriptionTypeDef = TypedDict(
-    "_OptionalPipelineDescriptionTypeDef",
-    {
-        "description": str,
-        "tags": List["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class PipelineDescriptionTypeDef(
-    _RequiredPipelineDescriptionTypeDef, _OptionalPipelineDescriptionTypeDef
-):
-    pass
-
 
 PipelineIdNameTypeDef = TypedDict(
     "PipelineIdNameTypeDef",
     {
-        "id": str,
-        "name": str,
+        "id": NotRequired[str],
+        "name": NotRequired[str],
     },
-    total=False,
 )
 
 PipelineObjectTypeDef = TypedDict(
@@ -392,27 +299,14 @@ PipelineObjectTypeDef = TypedDict(
     },
 )
 
-_RequiredPollForTaskInputRequestTypeDef = TypedDict(
-    "_RequiredPollForTaskInputRequestTypeDef",
+PollForTaskInputRequestTypeDef = TypedDict(
+    "PollForTaskInputRequestTypeDef",
     {
         "workerGroup": str,
+        "hostname": NotRequired[str],
+        "instanceIdentity": NotRequired["InstanceIdentityTypeDef"],
     },
 )
-_OptionalPollForTaskInputRequestTypeDef = TypedDict(
-    "_OptionalPollForTaskInputRequestTypeDef",
-    {
-        "hostname": str,
-        "instanceIdentity": "InstanceIdentityTypeDef",
-    },
-    total=False,
-)
-
-
-class PollForTaskInputRequestTypeDef(
-    _RequiredPollForTaskInputRequestTypeDef, _OptionalPollForTaskInputRequestTypeDef
-):
-    pass
-
 
 PollForTaskOutputTypeDef = TypedDict(
     "PollForTaskOutputTypeDef",
@@ -422,29 +316,15 @@ PollForTaskOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredPutPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_RequiredPutPipelineDefinitionInputRequestTypeDef",
+PutPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "PutPipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
         "pipelineObjects": Sequence["PipelineObjectTypeDef"],
+        "parameterObjects": NotRequired[Sequence["ParameterObjectTypeDef"]],
+        "parameterValues": NotRequired[Sequence["ParameterValueTypeDef"]],
     },
 )
-_OptionalPutPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_OptionalPutPipelineDefinitionInputRequestTypeDef",
-    {
-        "parameterObjects": Sequence["ParameterObjectTypeDef"],
-        "parameterValues": Sequence["ParameterValueTypeDef"],
-    },
-    total=False,
-)
-
-
-class PutPipelineDefinitionInputRequestTypeDef(
-    _RequiredPutPipelineDefinitionInputRequestTypeDef,
-    _OptionalPutPipelineDefinitionInputRequestTypeDef,
-):
-    pass
-
 
 PutPipelineDefinitionOutputTypeDef = TypedDict(
     "PutPipelineDefinitionOutputTypeDef",
@@ -456,29 +336,16 @@ PutPipelineDefinitionOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredQueryObjectsInputRequestTypeDef = TypedDict(
-    "_RequiredQueryObjectsInputRequestTypeDef",
+QueryObjectsInputRequestTypeDef = TypedDict(
+    "QueryObjectsInputRequestTypeDef",
     {
         "pipelineId": str,
         "sphere": str,
+        "query": NotRequired["QueryTypeDef"],
+        "marker": NotRequired[str],
+        "limit": NotRequired[int],
     },
 )
-_OptionalQueryObjectsInputRequestTypeDef = TypedDict(
-    "_OptionalQueryObjectsInputRequestTypeDef",
-    {
-        "query": "QueryTypeDef",
-        "marker": str,
-        "limit": int,
-    },
-    total=False,
-)
-
-
-class QueryObjectsInputRequestTypeDef(
-    _RequiredQueryObjectsInputRequestTypeDef, _OptionalQueryObjectsInputRequestTypeDef
-):
-    pass
-
 
 QueryObjectsOutputTypeDef = TypedDict(
     "QueryObjectsOutputTypeDef",
@@ -493,9 +360,8 @@ QueryObjectsOutputTypeDef = TypedDict(
 QueryTypeDef = TypedDict(
     "QueryTypeDef",
     {
-        "selectors": Sequence["SelectorTypeDef"],
+        "selectors": NotRequired[Sequence["SelectorTypeDef"]],
     },
-    total=False,
 )
 
 RemoveTagsInputRequestTypeDef = TypedDict(
@@ -506,26 +372,13 @@ RemoveTagsInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredReportTaskProgressInputRequestTypeDef = TypedDict(
-    "_RequiredReportTaskProgressInputRequestTypeDef",
+ReportTaskProgressInputRequestTypeDef = TypedDict(
+    "ReportTaskProgressInputRequestTypeDef",
     {
         "taskId": str,
+        "fields": NotRequired[Sequence["FieldTypeDef"]],
     },
 )
-_OptionalReportTaskProgressInputRequestTypeDef = TypedDict(
-    "_OptionalReportTaskProgressInputRequestTypeDef",
-    {
-        "fields": Sequence["FieldTypeDef"],
-    },
-    total=False,
-)
-
-
-class ReportTaskProgressInputRequestTypeDef(
-    _RequiredReportTaskProgressInputRequestTypeDef, _OptionalReportTaskProgressInputRequestTypeDef
-):
-    pass
-
 
 ReportTaskProgressOutputTypeDef = TypedDict(
     "ReportTaskProgressOutputTypeDef",
@@ -535,28 +388,14 @@ ReportTaskProgressOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredReportTaskRunnerHeartbeatInputRequestTypeDef = TypedDict(
-    "_RequiredReportTaskRunnerHeartbeatInputRequestTypeDef",
+ReportTaskRunnerHeartbeatInputRequestTypeDef = TypedDict(
+    "ReportTaskRunnerHeartbeatInputRequestTypeDef",
     {
         "taskrunnerId": str,
+        "workerGroup": NotRequired[str],
+        "hostname": NotRequired[str],
     },
 )
-_OptionalReportTaskRunnerHeartbeatInputRequestTypeDef = TypedDict(
-    "_OptionalReportTaskRunnerHeartbeatInputRequestTypeDef",
-    {
-        "workerGroup": str,
-        "hostname": str,
-    },
-    total=False,
-)
-
-
-class ReportTaskRunnerHeartbeatInputRequestTypeDef(
-    _RequiredReportTaskRunnerHeartbeatInputRequestTypeDef,
-    _OptionalReportTaskRunnerHeartbeatInputRequestTypeDef,
-):
-    pass
-
 
 ReportTaskRunnerHeartbeatOutputTypeDef = TypedDict(
     "ReportTaskRunnerHeartbeatOutputTypeDef",
@@ -580,10 +419,9 @@ ResponseMetadataTypeDef = TypedDict(
 SelectorTypeDef = TypedDict(
     "SelectorTypeDef",
     {
-        "fieldName": str,
-        "operator": "OperatorTypeDef",
+        "fieldName": NotRequired[str],
+        "operator": NotRequired["OperatorTypeDef"],
     },
-    total=False,
 )
 
 SetStatusInputRequestTypeDef = TypedDict(
@@ -595,29 +433,16 @@ SetStatusInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredSetTaskStatusInputRequestTypeDef = TypedDict(
-    "_RequiredSetTaskStatusInputRequestTypeDef",
+SetTaskStatusInputRequestTypeDef = TypedDict(
+    "SetTaskStatusInputRequestTypeDef",
     {
         "taskId": str,
         "taskStatus": TaskStatusType,
+        "errorId": NotRequired[str],
+        "errorMessage": NotRequired[str],
+        "errorStackTrace": NotRequired[str],
     },
 )
-_OptionalSetTaskStatusInputRequestTypeDef = TypedDict(
-    "_OptionalSetTaskStatusInputRequestTypeDef",
-    {
-        "errorId": str,
-        "errorMessage": str,
-        "errorStackTrace": str,
-    },
-    total=False,
-)
-
-
-class SetTaskStatusInputRequestTypeDef(
-    _RequiredSetTaskStatusInputRequestTypeDef, _OptionalSetTaskStatusInputRequestTypeDef
-):
-    pass
-
 
 TagTypeDef = TypedDict(
     "TagTypeDef",
@@ -630,37 +455,22 @@ TagTypeDef = TypedDict(
 TaskObjectTypeDef = TypedDict(
     "TaskObjectTypeDef",
     {
-        "taskId": str,
-        "pipelineId": str,
-        "attemptId": str,
-        "objects": Dict[str, "PipelineObjectTypeDef"],
+        "taskId": NotRequired[str],
+        "pipelineId": NotRequired[str],
+        "attemptId": NotRequired[str],
+        "objects": NotRequired[Dict[str, "PipelineObjectTypeDef"]],
     },
-    total=False,
 )
 
-_RequiredValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_RequiredValidatePipelineDefinitionInputRequestTypeDef",
+ValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
+    "ValidatePipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
         "pipelineObjects": Sequence["PipelineObjectTypeDef"],
+        "parameterObjects": NotRequired[Sequence["ParameterObjectTypeDef"]],
+        "parameterValues": NotRequired[Sequence["ParameterValueTypeDef"]],
     },
 )
-_OptionalValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_OptionalValidatePipelineDefinitionInputRequestTypeDef",
-    {
-        "parameterObjects": Sequence["ParameterObjectTypeDef"],
-        "parameterValues": Sequence["ParameterValueTypeDef"],
-    },
-    total=False,
-)
-
-
-class ValidatePipelineDefinitionInputRequestTypeDef(
-    _RequiredValidatePipelineDefinitionInputRequestTypeDef,
-    _OptionalValidatePipelineDefinitionInputRequestTypeDef,
-):
-    pass
-
 
 ValidatePipelineDefinitionOutputTypeDef = TypedDict(
     "ValidatePipelineDefinitionOutputTypeDef",
@@ -675,17 +485,15 @@ ValidatePipelineDefinitionOutputTypeDef = TypedDict(
 ValidationErrorTypeDef = TypedDict(
     "ValidationErrorTypeDef",
     {
-        "id": str,
-        "errors": List[str],
+        "id": NotRequired[str],
+        "errors": NotRequired[List[str]],
     },
-    total=False,
 )
 
 ValidationWarningTypeDef = TypedDict(
     "ValidationWarningTypeDef",
     {
-        "id": str,
-        "warnings": List[str],
+        "id": NotRequired[str],
+        "warnings": NotRequired[List[str]],
     },
-    total=False,
 )
